=========
Tutorials
=========

This page contains more in-depth guides for using PyEBSDIndex. It is broken up into
sections covering specific topics.

For descriptions of the functions, modules, and objects in PyEBSDIndex, see the
:doc:`/reference/index`.

Indexing
========

.. nbgallery::

    ebsd_index_demo

Pattern processing
==================

.. nbgallery::

    NLPAR_demo
